Struct data_streaming_service::streaming_client::ContinuouslyStreamTransactionOutputsRequest [−][src]
pub struct ContinuouslyStreamTransactionOutputsRequest {
pub start_version: Version,
pub start_epoch: Epoch,
pub target: Option<LedgerInfoWithSignatures>,
}Expand description
A client request for continuously streaming transaction outputs with proofs
Fields
start_version: Versionstart_epoch: Epochtarget: Option<LedgerInfoWithSignatures>Trait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.