Struct data_streaming_service::streaming_client::GetAllTransactionOutputsRequest [−][src]
pub struct GetAllTransactionOutputsRequest {
pub start_version: Version,
pub end_version: Version,
pub proof_version: Version,
}Expand description
A client request for fetching all transaction outputs with proofs.
Fields
start_version: Versionend_version: Versionproof_version: VersionTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.