Struct data_streaming_service::streaming_client::StreamRequestMessage [−][src]
pub struct StreamRequestMessage {
pub stream_request: StreamRequest,
pub response_sender: Sender<Result<DataStreamListener, Error>>,
}Expand description
Messages used by the data streaming client for communication with the
streaming service. The streaming service will respond to the client request
through the given response_sender.
Fields
stream_request: StreamRequestresponse_sender: Sender<Result<DataStreamListener, Error>>Trait Implementations