Struct data_streaming_service::streaming_client::TerminateStreamRequest [−][src]
pub struct TerminateStreamRequest {
pub notification_id: NotificationId,
pub notification_feedback: NotificationFeedback,
}Expand description
A client request for terminating a stream and providing payload feedback.
Fields
notification_id: NotificationIdnotification_feedback: NotificationFeedbackTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.